function J = cm_cost(w, X, gamma)

% Constant modulus (CM) cost function value.
%
%
% SYNTAX: J = cm_cost(w, X, gamma);
%
% OUTPUT:
%         J     : cost function value
%
% INPUTS:
%         w     : equalizer vector taps
%
%         X     : observed data matrix
%
%         gamma : constellation-dependent constant used in CM criterion.
%
%
% REFERENCES:
%
% - V. Zarzoso, P. Comon and D. Slock, <a href = "http://www.elsevier.com/books/handbook-of-blind-source-separation/comon/978-0-12-374726-6#description">"Semi-Blind Methods for Communications"</a>,
%   in: P. Comon and C. Jutten (Eds.), Handbook of Blind Source Separation, Independent Component Analysis and
%   Applications, Oxford, UK: Academic Press, 2010, chapter 15, pp. 593-638.
%
% - V. Zarzoso and P. Comon, <a href = "http://www.i3s.unice.fr/~zarzoso/biblio/tcom08.pdf">"Optimal Step-Size Constant Modulus Algorithm"</a>,
%   IEEE Transactions on Communications, Vol. 56, No. 1, January 2008, pp. 10-13
%
% - V. Zarzoso et P. Comon, <a href = "http://www.lavoisier.fr/notice/fr2746215180.html">"Methodes semi-aveugles pour les telecommunications"</a>,
%   dans : C. Jutten et P. Comon, Separation de sources 2 : au-dela de l'aveugle et applications,
%   Paris : Hermes, 2007, chapitre 8, pp. 303-353.
%
% - V. Zarzoso and P. Comon, <a href = "http://www.i3s.unice.fr/~zarzoso/biblio/icassp05.pdf">"Semi-Blind Constant Modulus Equalization with Optimal Step Size"</a>,
%   in: Proceedings ICASSP-2005, 30th IEEE International Conference on Acoustics, Speech and Signal Processing,
%   Philadelphia, PA, March 18-23, 2005, Vol. III, pp. 577-580. 
%
% - V. Zarzoso and P. Comon, <a href = "http://www.i3s.unice.fr/~zarzoso/biblio/eusipco05.pdf">"Blind Channel Equalization with Algebraic Optimal Step Size"</a>,
%   in: Proceedings EUSIPCO-2005, XIII European Signal Processing Conference, Antalya, Turkey, September 4-8, 2005.
%
%
% Please, report any bugs, comments or suggestions to <a href = "mailto:zarzoso@i3s.unice.fr">zarzoso(a)i3s.unice.fr</a>.
%
%
% HISTORY:
% 
%    <Please add modification date here>: - <please add modification details here>
%         
% -- 2014/11/21: Version 1 release ----------------------------------------------------------------
%
%    2010/02/18: - created by Vicente Zarzoso
%                  (I3S Laboratory, University of Nice Sophia Antipolis, CNRS, France).


T = length(X);
b = abs(w'*X).^2 - gamma;  
J = b*b'/T;

    