% OS-CMA for blind channel equalization and signal extraction (Release 1 - November 21, 2014)
% -------------------------------------------------------------------------------------------
%
% The optimal step-size constant modulus algorithm (OS-CMA) is based on a computationally
% efficient iterative technique to minimize the CM cost function. This technique computes
% algebraically the step size (adaption coefficient) globally minimizing the CM contrast in
% the search direction at each iteration.
%
% More details about the OS-CMA and its comparative performance analysis can be in
% references [1]-[5] below. You can also visit:
%
%    <a href = "http://www.i3s.unice.fr/~zarzoso/oscma.html">http://www.i3s.unice.fr/~zarzoso/oscma.html</a>
%
%
% M-FILES:
%
% The package is composed of the following M-files:
%                                          
%  - <a href = "matlab:doc os_cma">os_cma.m</a>:      implements the algorithm itself in batch processing mode.
%
%  - <a href = "matlab:doc cm_cost">cm_cost.m</a>:     computes the CM cost function value.
%
%  - <a href = "matlab:doc os_cma_demo">os_cma_demo.m</a>: a simple demonstration illustrating the performance of the OS-CMA.
%   
%  - <a href = "matlab:doc contents.m">contents.m</a>:    this help.
%
%
% CONDITIONS OF USE:
% 
%    This is open-source code. Please, feel free to edit the M-files and modify them as you wish.
%    It is only requested that original authorship be acknowledged and modifications be clearly
%    indicated in the code (history section and elsewhere as appropriate).
%     
%    If you use this package to generate results in your publications, please cite at least
%    reference [2].
%
%    This code is licensed under a <a href="http://creativecommons.org/licenses/by-nc/4.0/">Creative Commons Attribution-NonCommercial 4.0 International License</a>.
%
%
% COMPATIBILITY:
% 
%    The package has been tested on Matlab 7.14. 
%
%
% UPDATES:
% 
%    To download the latest version of the package, please visit the OS-CMA webpage:
%
%       <a href = "http://www.i3s.unice.fr/~zarzoso/oscma.html">http://www.i3s.unice.fr/~zarzoso/oscma.html</a>
%
%
% FEEDBACK:
% 
%    Please, report any bugs, comments or suggestions to <a href = "mailto:zarzoso@i3s.unice.fr">zarzoso(a)i3s.unice.fr</a>.
%
%
% REFERENCES:
%  
% [1] V. Zarzoso, P. Comon and D. Slock, <a href = "http://www.elsevier.com/books/handbook-of-blind-source-separation/comon/978-0-12-374726-6#description">"Semi-Blind Methods for Communications"</a>,
%     in: P. Comon and C. Jutten (Eds.), Handbook of Blind Source Separation, Independent Component Analysis and
%     Applications, Oxford, UK: Academic Press, 2010, chapter 15, pp. 593-638.
%
% [2] V. Zarzoso and P. Comon, <a href = "http://www.i3s.unice.fr/~zarzoso/biblio/tcom08.pdf">"Optimal Step-Size Constant Modulus Algorithm"</a>,
%     IEEE Transactions on Communications, Vol. 56, No. 1, January 2008, pp. 10-13
%
% [3] V. Zarzoso et P. Comon, <a href = "http://www.lavoisier.fr/notice/fr2746215180.html">"Methodes semi-aveugles pour les telecommunications"</a>,
%     dans : C. Jutten et P. Comon, Separation de sources 2 : au-dela de l'aveugle et applications,
%     Paris : Hermes, 2007, chapitre 8, pp. 303-353.
%
% [4] V. Zarzoso and P. Comon, <a href = "http://www.i3s.unice.fr/~zarzoso/biblio/icassp05.pdf">"Semi-Blind Constant Modulus Equalization with Optimal Step Size"</a>,
%     in: Proceedings ICASSP-2005, 30th IEEE International Conference on Acoustics, Speech and Signal Processing,
%     Philadelphia, PA, March 18-23, 2005, Vol. III, pp. 577-580. 
%
% [5] V. Zarzoso and P. Comon, <a href = "http://www.i3s.unice.fr/~zarzoso/biblio/eusipco05.pdf">"Blind Channel Equalization with Algebraic Optimal Step Size"</a>,
%     in: Proceedings EUSIPCO-2005, XIII European Signal Processing Conference, Antalya, Turkey, September 4-8, 2005.
%

